Redkyn-common |pypi| |travis|
=============================

.. |pypi| image:: https://badge.fury.io/py/redkyn-common.svg
    :target: https://badge.fury.io/py/redkyn-common

.. |travis| image:: https://travis-ci.org/redkyn/redkyn-common.svg?branch=master
    :target: https://travis-ci.org/redkyn/redkyn-common

Common libraries for `Assigner <https://github.com/redkyn/assigner>`_ and `Grader <https://github.com/redkyn/grader>`_.

Libraries
---------
- ``canvas``: An API wrapper for getting course information from Canvas
